@@ -2,67 +2,83 @@ sarima <-
 function(xdata,p,d,q,P=0,D=0,Q=0,S=-1,details=TRUE,xreg=NULL,Model=TRUE,
           fixed=NULL,tol=sqrt(.Machine$double.eps),no.constant=FALSE, ...)
 { 
-   arima = stats::arima
-   #
+
    trans = ifelse (is.null(fixed), TRUE, FALSE)
    trc   = ifelse(details, 1, 0)
-   n     = length(xdata)
- if (is.null(xreg)) {
+   n     = length(xdata) 
+  if (is.null(xreg)) {
    constant = 1:n 
    xmean    = rep(1,n)  
-   if (no.constant==TRUE)  xmean=NULL 
-   if (d==0 & D==0) {	  
+   if (no.constant)  xmean=NULL 
+   if (d==0 & D==0) {  
            fitit = arima(xdata, order=c(p,d,q), seasonal=list(order=c(P,D,Q), period=S),
-                  xreg=xmean, include.mean=FALSE, fixed=fixed, trans=trans, 
+                  xreg=xmean, include.mean=FALSE, fixed=fixed, transform.pars=trans, 
                   optim.control=list(trace=trc, REPORT=1, reltol=tol))
     } else if (xor(d==1, D==1) & no.constant==FALSE) {
            fitit = arima(xdata, order=c(p,d,q), seasonal=list(order=c(P,D,Q), period=S),
-                   xreg=constant, fixed=fixed, trans=trans,
+                   xreg=constant, fixed=fixed, transform.pars=trans,
                    optim.control=list(trace=trc, REPORT=1, reltol=tol))
     } else fitit = arima(xdata, order=c(p,d,q), seasonal=list(order=c(P,D,Q), period=S), 
-                   include.mean=!no.constant, fixed=fixed, trans=trans, 
+                   include.mean=!no.constant, fixed=fixed, transform.pars=trans, 
                    optim.control=list(trace=trc, REPORT=1, reltol=tol))
-  }
-#
+  } 
+
   if (!is.null(xreg)) {
-    fitit = stats::arima(xdata, order=c(p,d,q), seasonal=list(order=c(P,D,Q), period=S), 
-                         xreg=xreg, fixed=fixed, trans=trans, 
+    fitit = arima(xdata, order=c(p,d,q), seasonal=list(order=c(P,D,Q), period=S), 
+                         xreg=xreg, fixed=fixed, transform.pars=trans, 
                          optim.control=list(trace=trc, REPORT=1, reltol=tol))
   }
+
+  if (is.null(fixed)) {coefs=fitit$coef
+    } else { coefs = fitit$coef[is.na(fixed)]
+    }
+  
+   k       = length(coefs) 
+   n       = fitit$nobs  # effective sample size
+   dfree   = n-k 
+   t.value = coefs/sqrt(diag(fitit$var.coef)) 
+   p.two   = stats::pf(t.value^2, df1=1, df2=dfree, lower.tail = FALSE)   
+   ttable  = cbind(Estimate=coefs, SE=sqrt(diag(fitit$var.coef)), t.value, p.value=p.two)
+   ttable  = round(ttable,4)
+   BIC     = stats::BIC(fitit)/n
+   AIC     = stats::AIC(fitit)/n
+   AICc    = (n*AIC + ( (2*k^2+2*k)/(n-k-1) ))/n
+
+
+# print  results
+  cat('<><><><><><><><><><><><><><>')
+  cat('\n','\n')
+  cat('Coefficients:', '\n')
+  print(ttable)
+  cat('\n')
+  cat('sigma^2 estimated as', fitit$sigma2, 'on', dfree, 'degrees of freedom', '\n','\n')
+  cat('AIC =', AIC, ' AICc =', AICc, ' BIC =', BIC, '\n', '\n')
+  out = list(fit=fitit, degrees_of_freedom=dfree, ttable=ttable, 
+             ICs=c(AIC=AIC, AICc=AICc, BIC=BIC))
+############################
+
 #  replace tsdiag with a better version
  if(details){
-   layout    = graphics::layout
-   par       = graphics::par
-   plot      = graphics::plot
-   acf       = stats::acf
-   polygon   = graphics::polygon
-   abline    = graphics::abline
-   lines     = graphics::lines
-   title     = graphics::title
-   frequency = stats::frequency
-   coef      = stats::coef
-   dnorm     = stats::dnorm
-   ppoints   = stats::ppoints
-   qnorm     = stats::qnorm
-   time      = stats::time
-   na.pass   = stats::na.pass
-   old.par  <- par(no.readonly = TRUE)
+  old.par  <- par(no.readonly = TRUE)
   layout(matrix(c(1,2,4, 1,3,4), ncol=2))
-   rs     <- fitit$residuals
+    rs <-  fitit$residuals 
    stdres <- rs/sqrt(fitit$sigma2)
    num    <- sum(!is.na(rs))
-   tsplot(stdres, main = "Standardized Residuals", ylab = "", ...)
+  tsplot(stdres, main = "Standardized Residuals", ylab = "", ...)
     if(Model){
-     if (S<0) {title(paste( "Model: (", p, "," ,d, "," ,q, ")", sep=""), adj=0) }
-     else {title(paste( "Model: (", p, "," ,d, "," ,q, ") ", "(", P, "," ,D, "," ,Q, ") [", S,"]",  sep=""), adj=0) }
+     if (S<0) {title(bquote('Model: ('~.(p)*','*.(d)*','*.(q)~')'), adj=0) }
+     else {title(bquote('Model: ('~.(p)*','*.(d)*','*.(q)~')'~'\u00D7'~'('~.(P)*','*.(D)*','*.(Q)~')'[~.(S)]), 
+                  adj=0) }     
     }
+
     alag  <- max(10+sqrt(num), 3*S) 
-    acf1(rs, alag, main = "ACF of Residuals", ...)   
-#    
+  acf1(rs, alag, main = "ACF of Residuals", ...)
+
     u = qqnorm(stdres, plot.it=FALSE)
-    lwr = min(-4, min(stdres)); upr = max(4, max(stdres))
-    tsplot(u$x, u$y, type='p', ylim=c(lwr,upr), ylab="Sample Quantiles", xlab="Theoretical Quantiles",  
+    lwr = min(-4, min(stdres, na.rm=TRUE)); upr = max(4, max(stdres), na.rm=TRUE)
+  tsplot(u$x, u$y, type='p', ylim=c(lwr,upr), ylab="Sample Quantiles", xlab="Theoretical Quantiles",  
            main="Normal Q-Q Plot of Std Residuals",  ...)	
+
      ################ qq error bnds ###########
        sR  <- !is.na(stdres)
        ord <- order(stdres[sR])
@@ -90,24 +106,10 @@ function(xdata,p,d,q,P=0,D=0,Q=0,S=-1,details=TRUE,xreg=NULL,Model=TRUE,
     pval <- numeric(nlag)
     for (i in (ppq+1):nlag) {u <- stats::Box.test(rs, i, type = "Ljung-Box")$statistic
                              pval[i] <- stats::pchisq(u, i-ppq, lower.tail=FALSE)}            
-     tsplot( (ppq+1):nlag, pval[(ppq+1):nlag], type='p', xlab = "LAG (H)", ylab = "p value", 
+  tsplot( (ppq+1):nlag, pval[(ppq+1):nlag], type='p', xlab = "LAG (H)", ylab = "p value", 
               ylim = c(-.14, 1), main = "p values for Ljung-Box statistic", ...)
-     abline(h = 0.05, lty = 2, col = 4)  
-    on.exit(par(old.par)) 
-}	
-#  end new tsdiag
-   if (is.null(fixed)) {coefs=fitit$coef
-    } else { coefs = fitit$coef[is.na(fixed)]
-    }  
-   k       = length(coefs) 
-   n       = fitit$nobs  # effective sample size
-   dfree   = n-k 
-   t.value = coefs/sqrt(diag(fitit$var.coef)) 
-   p.two   = stats::pf(t.value^2, df1=1, df2=dfree, lower.tail = FALSE)   
-   ttable  = cbind(Estimate=coefs, SE=sqrt(diag(fitit$var.coef)), t.value, p.value=p.two)
-   ttable  = round(ttable,4)
-   BIC     = stats::BIC(fitit)/n
-   AIC     = stats::AIC(fitit)/n
-   AICc    = (n*AIC + ( (2*k^2+2*k)/(n-k-1) ))/n
-   list(fit=fitit, degrees_of_freedom=dfree, ttable=ttable, AIC=AIC, AICc=AICc, BIC=BIC)
+   abline(h = 0.05, lty = 2, col = 4)  
+   on.exit(par(old.par)) 
+}  #  end new tsdiag
+invisible(out)
 }
\ No newline at end of file
